# HyresBuilder: A simple package for building HyRes peptide model.   
This package is forked from [PeptideBuilder](https://github.com/clauswilke/PeptideBuilder) and we do some modifications for HyRes.   
Thanks for the contribution of PeptideBuilder.    
Shanlong Li    

## Installation:   
pip install HyresBuilder


## Basic usage:   
This package builds HyRes peptide structure from sequence. Please see the [examples](examples) for details.   
To obtain psf file and further run simulation on OpenMM, please follow these [instructions](https://github.com/wayuer19/HyRes_GPU).   
>[!NOTE]
>After obtaining the pdb files, the initial structures need to be relaxed to get more reasonable state.   
